app

package
v1.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 1, 2019 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Main

func Main(args []string) error

Main represents the usual main method of the whole program. It is moved to its own package to testing using go utils.

Types

This section is empty.

Source Files

  • help.go
  • main.go
  • utils.go

Jump to